==> siggenes_1.20.0.zip: siggenes/doc/siggenes.R <==
###################################################
### chunk number 1: 
###################################################
library(siggenes)


###################################################
### chunk number 2: 
###################################################
library(siggenes)


###################################################
### chunk number 3: 
###################################################
data(golub)


###################################################
### chunk number 4: 
###################################################
args(sam)


###################################################
### chunk number 5: 
###################################################
args(d.stat)


###################################################
### chunk number 6: 
###################################################
args.sam(summary)


###################################################
### chunk number 7: 
###################################################
n <- 10
rep(1, n)


###################################################
### chunk number 8: 
###################################################
n1 <- n2 <- 5
rep(c(0, 1), c(n1, n2))


###################################################
### chunk number 9: 
###################################################
K <- 5
c((-1:-5), 1:5)


###################################################
### chunk number 10: 
###################################################
K <- 5
rep(1:K, e = 2) * rep(c(-1 ,1), K)


###################################################
### chunk number 11: 
###################################################
K <- 5
cbind(rep(c(-1, 1), 5), rep(1:5, e = 2))


###################################################
### chunk number 12: 
###################################################
sam.out <- sam(golub, golub.cl, rand = 123, gene.names = golub.gnames[,3])
sam.out


###################################################
### chunk number 13: 
###################################################
sam.out2 <- sam(golub, golub.cl, method = wilc.stat, rand = 123)


###################################################
### chunk number 14: 
###################################################
summary(sam.out)


###################################################
### chunk number 15: 
###################################################
print(sam.out, seq(1.5, 2.4, 0.1))


###################################################
### chunk number 16: 
###################################################
sum.sam.out <- summary(sam.out, 3.3)
sum.sam.out


###################################################
### chunk number 17: 
###################################################
print(sum.sam.out, varNames = "Proteins")


###################################################
### chunk number 18: 
###################################################
sum.sam.out@row.sig.genes


###################################################
### chunk number 19: 
###################################################
sum.sam.out@mat.fdr


###################################################
### chunk number 20: 
###################################################
sum.sam.out@mat.sig


###################################################
### chunk number 21: 
###################################################
list.siggenes(sam.out, 3.3)


###################################################
### chunk number 22: 
###################################################
findDelta(sam.out, fdr = 0.05)


###################################################
### chunk number 23: 
###################################################
findDelta(sam.out, genes = 200)


###################################################
### chunk number 24: 
###################################################
find.out <- find.a0(golub, golub.cl, rand = 123)


###################################################
### chunk number 25: 
###################################################
find.out


###################################################
### chunk number 26: 
###################################################
print(find.out, 0.95)


###################################################
### chunk number 27: 
###################################################
ebam(find.out)


###################################################
### chunk number 28: 
###################################################
ebam(find.out, which.a0 = 2)


###################################################
### chunk number 29: 
###################################################
ebam(golub, golub.cl, a0 = 0, fast = TRUE, rand = 123)


###################################################
### chunk number 30: 
###################################################
ebam.out <- ebam(golub, golub.cl, a0 = 0, rand = 123)


###################################################
### chunk number 31: 
###################################################
print(ebam.out, seq(0.91, 0.99, 0.01))


###################################################
### chunk number 32: 
###################################################
summary(ebam.out, 0.99997)


###################################################
### chunk number 33: 
###################################################
ebam(golub, golub.cl, a0 = 0, var.equal = TRUE, rand = 123)


###################################################
### chunk number 34: 
###################################################
ebam(golub, golub.cl, quan.a0 = 0.5, rand = 123)


###################################################
### chunk number 35: 
###################################################
ebam(golub, golub.cl, method = wilc.ebam, rand =123)


###################################################
### chunk number 36: 
###################################################
t.stat <- function(data, cl){
    require(genefilter) ||
        stop("genefilter required.")
    cl <- as.factor(cl)
    row.out <- rowttests(data, cl)
    d <- row.out$statistic
    m <- length(na.exclude(d))
    d.bar <- qt(((1:m) - 0.5)/m, length(cl) - 2)
    p.value <- row.out$p.value
    vec.false <- m * p.value/2
    s <- row.out$dm/d
    msg <- paste("SAM Two-Class Analysis",
         "Assuming Normality\n\n")
    list(d = -d, d.bar = d.bar, p.value = p.value,
        vec.false = vec.false, s = s, s0 = 0,
        mat.samp = matrix(numeric(0)),
        msg = msg, fold = numeric(0))
}


###################################################
### chunk number 37: 
###################################################
sam(golub, golub.cl, method = t.stat)


###################################################
### chunk number 38: 
###################################################
t.find <- function(data, cl, B = 50){
    require(genefilter)
    z.fun <- function(data, cl){
        cl <- as.factor(cl)
        out <- rowttests(data, cl)
        r<- out$dm
        s<- r / out$statistic
        return(list(r = -r, s = s))
    }
    mat.samp <- matrix(0, B, length(cl))
    for(i in 1:B)
        mat.samp[i, ] <- sample(cl)
    z.out <- z.fun(data, cl)
    msg <- paste("EBAM Analysis with a Moderated t-Statistic\n\n")
    list(r = z.out$r, s = z.out$s,
        mat.samp = mat.samp, z.fun = z.fun, msg = msg)
}


###################################################
### chunk number 39: 
###################################################
t.out <- find.a0(golub, golub.cl, method = t.find, B = 100, rand =123)
t.out


###################################################
### chunk number 40: 
###################################################
find.a0(golub, golub.cl, var.equal = TRUE, rand =123)


###################################################
### chunk number 41: 
###################################################
ebam(t.out)


###################################################
### chunk number 42: 
###################################################
t.ebam<-function(data, cl){
    require(genefilter)
    cl <- as.factor(cl)
    out <- rowttests(data, cl)
    z <- -out$statistic
    z.dens <- denspr(z)$y
    m <- length(z)
    vec.pos <- m * out$p.value / 2
    z.null <- dt(z, length(cl) - 2)
    msg<-paste("EBAM Analysis with t-Statistic Assuming Normality.\n\n")
    list(z = z, ratio = z.null/z.dens, vec.pos = vec.pos,
        vec.neg = vec.pos, msg = msg)
}


###################################################
### chunk number 43: 
###################################################
ebam(golub, golub.cl, method = t.ebam)

==> siggenes_1.24.0.zip: siggenes/doc/siggenes.R <==
###################################################
### chunk number 1: 
###################################################
#line 61 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpAHE2YX/R.INSTALL3b57e94/siggenes/inst/doc/siggenes.Rnw"
library(siggenes)


###################################################
### chunk number 2: 
###################################################
#line 65 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpAHE2YX/R.INSTALL3b57e94/siggenes/inst/doc/siggenes.Rnw"
library(siggenes)


###################################################
### chunk number 3: 
###################################################
#line 75 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpAHE2YX/R.INSTALL3b57e94/siggenes/inst/doc/siggenes.Rnw"
data(golub)


###################################################
### chunk number 4: 
###################################################
#line 150 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpAHE2YX/R.INSTALL3b57e94/siggenes/inst/doc/siggenes.Rnw"
args(sam)


###################################################
### chunk number 5: 
###################################################
#line 156 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpAHE2YX/R.INSTALL3b57e94/siggenes/inst/doc/siggenes.Rnw"
args(d.stat)


###################################################
### chunk number 6: 
###################################################
#line 191 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpAHE2YX/R.INSTALL3b57e94/siggenes/inst/doc/siggenes.Rnw"
args.sam(summary)


###################################################
### chunk number 7: 
###################################################
#line 265 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpAHE2YX/R.INSTALL3b57e94/siggenes/inst/doc/siggenes.Rnw"
n <- 10
rep(1, n)


###################################################
### chunk number 8: 
###################################################
#line 281 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpAHE2YX/R.INSTALL3b57e94/siggenes/inst/doc/siggenes.Rnw"
n1 <- n2 <- 5
rep(c(0, 1), c(n1, n2))


###################################################
### chunk number 9: 
###################################################
#line 309 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpAHE2YX/R.INSTALL3b57e94/siggenes/inst/doc/siggenes.Rnw"
K <- 5
c((-1:-5), 1:5)


###################################################
### chunk number 10: 
###################################################
#line 323 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpAHE2YX/R.INSTALL3b57e94/siggenes/inst/doc/siggenes.Rnw"
K <- 5
rep(1:K, e = 2) * rep(c(-1 ,1), K)


###################################################
### chunk number 11: 
###################################################
#line 336 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpAHE2YX/R.INSTALL3b57e94/siggenes/inst/doc/siggenes.Rnw"
K <- 5
cbind(rep(c(-1, 1), 5), rep(1:5, e = 2))


###################################################
### chunk number 12: 
###################################################
#line 375 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpAHE2YX/R.INSTALL3b57e94/siggenes/inst/doc/siggenes.Rnw"
sam.out <- sam(golub, golub.cl, rand = 123, gene.names = golub.gnames[,3])
sam.out


###################################################
### chunk number 13: 
###################################################
#line 401 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpAHE2YX/R.INSTALL3b57e94/siggenes/inst/doc/siggenes.Rnw"
sam.out2 <- sam(golub, golub.cl, method = wilc.stat, rand = 123)


###################################################
### chunk number 14: 
###################################################
#line 407 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpAHE2YX/R.INSTALL3b57e94/siggenes/inst/doc/siggenes.Rnw"
summary(sam.out)


###################################################
### chunk number 15: 
###################################################
#line 421 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpAHE2YX/R.INSTALL3b57e94/siggenes/inst/doc/siggenes.Rnw"
print(sam.out, seq(1.5, 2.4, 0.1))


###################################################
### chunk number 16: 
###################################################
#line 471 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpAHE2YX/R.INSTALL3b57e94/siggenes/inst/doc/siggenes.Rnw"
sum.sam.out <- summary(sam.out, 3.3)
sum.sam.out


###################################################
### chunk number 17: 
###################################################
#line 486 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpAHE2YX/R.INSTALL3b57e94/siggenes/inst/doc/siggenes.Rnw"
print(sum.sam.out, varNames = "Proteins")


###################################################
### chunk number 18: 
###################################################
#line 495 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpAHE2YX/R.INSTALL3b57e94/siggenes/inst/doc/siggenes.Rnw"
sum.sam.out@row.sig.genes


###################################################
### chunk number 19: 
###################################################
#line 501 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpAHE2YX/R.INSTALL3b57e94/siggenes/inst/doc/siggenes.Rnw"
sum.sam.out@mat.fdr


###################################################
### chunk number 20: 
###################################################
#line 507 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpAHE2YX/R.INSTALL3b57e94/siggenes/inst/doc/siggenes.Rnw"
sum.sam.out@mat.sig


###################################################
### chunk number 21: 
###################################################
#line 513 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpAHE2YX/R.INSTALL3b57e94/siggenes/inst/doc/siggenes.Rnw"
list.siggenes(sam.out, 3.3)


###################################################
### chunk number 22: 
###################################################
#line 521 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpAHE2YX/R.INSTALL3b57e94/siggenes/inst/doc/siggenes.Rnw"
findDelta(sam.out, fdr = 0.05)


###################################################
### chunk number 23: 
###################################################
#line 535 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpAHE2YX/R.INSTALL3b57e94/siggenes/inst/doc/siggenes.Rnw"
findDelta(sam.out, genes = 200)


###################################################
### chunk number 24: 
###################################################
#line 554 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpAHE2YX/R.INSTALL3b57e94/siggenes/inst/doc/siggenes.Rnw"
find.out <- find.a0(golub, golub.cl, rand = 123)


###################################################
### chunk number 25: 
###################################################
#line 561 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpAHE2YX/R.INSTALL3b57e94/siggenes/inst/doc/siggenes.Rnw"
find.out


###################################################
### chunk number 26: 
###################################################
#line 570 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpAHE2YX/R.INSTALL3b57e94/siggenes/inst/doc/siggenes.Rnw"
print(find.out, 0.95)


###################################################
### chunk number 27: 
###################################################
#line 605 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpAHE2YX/R.INSTALL3b57e94/siggenes/inst/doc/siggenes.Rnw"
ebam(find.out)


###################################################
### chunk number 28: 
###################################################
#line 613 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpAHE2YX/R.INSTALL3b57e94/siggenes/inst/doc/siggenes.Rnw"
ebam(find.out, which.a0 = 2)


###################################################
### chunk number 29: 
###################################################
#line 626 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpAHE2YX/R.INSTALL3b57e94/siggenes/inst/doc/siggenes.Rnw"
ebam(golub, golub.cl, a0 = 0, fast = TRUE, rand = 123)


###################################################
### chunk number 30: 
###################################################
#line 641 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpAHE2YX/R.INSTALL3b57e94/siggenes/inst/doc/siggenes.Rnw"
ebam.out <- ebam(golub, golub.cl, a0 = 0, rand = 123)


###################################################
### chunk number 31: 
###################################################
#line 652 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpAHE2YX/R.INSTALL3b57e94/siggenes/inst/doc/siggenes.Rnw"
print(ebam.out, seq(0.91, 0.99, 0.01))


###################################################
### chunk number 32: 
###################################################
#line 676 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpAHE2YX/R.INSTALL3b57e94/siggenes/inst/doc/siggenes.Rnw"
summary(ebam.out, 0.99997)


###################################################
### chunk number 33: 
###################################################
#line 694 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpAHE2YX/R.INSTALL3b57e94/siggenes/inst/doc/siggenes.Rnw"
ebam(golub, golub.cl, a0 = 0, var.equal = TRUE, rand = 123)


###################################################
### chunk number 34: 
###################################################
#line 702 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpAHE2YX/R.INSTALL3b57e94/siggenes/inst/doc/siggenes.Rnw"
ebam(golub, golub.cl, quan.a0 = 0.5, rand = 123)


###################################################
### chunk number 35: 
###################################################
#line 710 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpAHE2YX/R.INSTALL3b57e94/siggenes/inst/doc/siggenes.Rnw"
ebam(golub, golub.cl, method = wilc.ebam, rand =123)


###################################################
### chunk number 36: 
###################################################
#line 778 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpAHE2YX/R.INSTALL3b57e94/siggenes/inst/doc/siggenes.Rnw"
t.stat <- function(data, cl){
    require(genefilter) ||
        stop("genefilter required.")
    cl <- as.factor(cl)
    row.out <- rowttests(data, cl)
    d <- row.out$statistic
    m <- length(na.exclude(d))
    d.bar <- qt(((1:m) - 0.5)/m, length(cl) - 2)
    p.value <- row.out$p.value
    vec.false <- m * p.value/2
    s <- row.out$dm/d
    msg <- paste("SAM Two-Class Analysis",
         "Assuming Normality\n\n")
    list(d = -d, d.bar = d.bar, p.value = p.value,
        vec.false = vec.false, s = s, s0 = 0,
        mat.samp = matrix(numeric(0)),
        msg = msg, fold = numeric(0))
}


###################################################
### chunk number 37: 
###################################################
#line 809 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpAHE2YX/R.INSTALL3b57e94/siggenes/inst/doc/siggenes.Rnw"
sam(golub, golub.cl, method = t.stat)


###################################################
### chunk number 38: 
###################################################
#line 855 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpAHE2YX/R.INSTALL3b57e94/siggenes/inst/doc/siggenes.Rnw"
t.find <- function(data, cl, B = 50){
    require(genefilter)
    z.fun <- function(data, cl){
        cl <- as.factor(cl)
        out <- rowttests(data, cl)
        r<- out$dm
        s<- r / out$statistic
        return(list(r = -r, s = s))
    }
    mat.samp <- matrix(0, B, length(cl))
    for(i in 1:B)
        mat.samp[i, ] <- sample(cl)
    z.out <- z.fun(data, cl)
    msg <- paste("EBAM Analysis with a Moderated t-Statistic\n\n")
    list(r = z.out$r, s = z.out$s,
        mat.samp = mat.samp, z.fun = z.fun, msg = msg)
}


###################################################
### chunk number 39: 
###################################################
#line 882 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpAHE2YX/R.INSTALL3b57e94/siggenes/inst/doc/siggenes.Rnw"
t.out <- find.a0(golub, golub.cl, method = t.find, B = 100, rand =123)
t.out


###################################################
### chunk number 40: 
###################################################
#line 889 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpAHE2YX/R.INSTALL3b57e94/siggenes/inst/doc/siggenes.Rnw"
find.a0(golub, golub.cl, var.equal = TRUE, rand =123)


###################################################
### chunk number 41: 
###################################################
#line 895 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpAHE2YX/R.INSTALL3b57e94/siggenes/inst/doc/siggenes.Rnw"
ebam(t.out)


###################################################
### chunk number 42: 
###################################################
#line 929 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpAHE2YX/R.INSTALL3b57e94/siggenes/inst/doc/siggenes.Rnw"
t.ebam<-function(data, cl){
    require(genefilter)
    cl <- as.factor(cl)
    out <- rowttests(data, cl)
    z <- -out$statistic
    z.dens <- denspr(z)$y
    m <- length(z)
    vec.pos <- m * out$p.value / 2
    z.null <- dt(z, length(cl) - 2)
    msg<-paste("EBAM Analysis with t-Statistic Assuming Normality.\n\n")
    list(z = z, ratio = z.null/z.dens, vec.pos = vec.pos,
        vec.neg = vec.pos, msg = msg)
}


###################################################
### chunk number 43: 
###################################################
#line 952 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpAHE2YX/R.INSTALL3b57e94/siggenes/inst/doc/siggenes.Rnw"
ebam(golub, golub.cl, method = t.ebam)
